@@ -26,7 +26,7 @@ import string
 import random
 
 # ghcontrol version shares release major and minor numbers with GH HIS.
-VERSION = "5.0.0"  # gnuheath-control version
+VERSION = "5.0.2"  # gnuheath-control version
 MIN_VER = '>=5.0.0a1,<5.1'  # Initial gnuhealth server package version
 TRYTON_PINNING = '>=7.0,<7.1'   # Pin the tryton packages to this range
 
@@ -371,7 +371,7 @@ $EDITOR {trytond_cfg} \"$@\"
             file_content = f"""\
 # Generated by gnuhealth-control
 [database]
-uri = postgresql://localhost:5432
+uri = postgresql://
 path = {his_dir}/attach
 
 [web]
@@ -406,7 +406,7 @@ formatter=simple
 args=(sys.stdout,)
 
 [logger_root]
-level=INFO
+level=WARNING
 handlers=rotate,console
 """
 
